@@ -114,14 +114,10 @@ impl Pattern {
         candidate: &str,
     ) -> Option<NameMatch> {
         match self {
-            Self::NameExact(ep) => ep.find(candidate),
-            Self::NameFuzzy(fp) => fp.find(candidate),
-            Self::NameRegex(rp) => rp.find(candidate),
-            Self::NameTokens(tp) => tp.find(candidate),
-            Self::PathExact(ep) => ep.find(candidate),
-            Self::PathFuzzy(fp) => fp.find(candidate),
-            Self::PathRegex(rp) => rp.find(candidate),
-            Self::PathTokens(tp) => tp.find(candidate),
+            Self::NameExact(ep) | Self::PathExact(ep) => ep.find(candidate),
+            Self::NameFuzzy(fp) | Self::PathFuzzy(fp) => fp.find(candidate),
+            Self::NameRegex(rp) | Self::PathRegex(rp) => rp.find(candidate),
+            Self::NameTokens(tp) | Self::PathTokens(tp) => tp.find(candidate),
             Self::Composite(cp) => cp.search_string(candidate),
             _ => None,
         }
@@ -157,14 +153,14 @@ impl Pattern {
 
     pub fn score_of(&self, candidate: Candidate) -> Option<i32> {
         match self {
-            Self::NameExact(ep) => ep.score_of(&candidate.name),
-            Self::NameFuzzy(fp) => fp.score_of(&candidate.name),
-            Self::NameRegex(rp) => rp.find(&candidate.name).map(|m| m.score),
-            Self::NameTokens(tp) => tp.score_of(&candidate.name),
-            Self::PathExact(ep) => ep.score_of(&candidate.subpath),
-            Self::PathFuzzy(fp) => fp.score_of(&candidate.subpath),
-            Self::PathRegex(rp) => rp.find(&candidate.subpath).map(|m| m.score),
-            Self::PathTokens(tp) => tp.score_of(&candidate.subpath),
+            Self::NameExact(ep) => ep.score_of(candidate.name),
+            Self::NameFuzzy(fp) => fp.score_of(candidate.name),
+            Self::NameRegex(rp) => rp.find(candidate.name).map(|m| m.score),
+            Self::NameTokens(tp) => tp.score_of(candidate.name),
+            Self::PathExact(ep) => ep.score_of(candidate.subpath),
+            Self::PathFuzzy(fp) => fp.score_of(candidate.subpath),
+            Self::PathRegex(rp) => rp.find(candidate.subpath).map(|m| m.score),
+            Self::PathTokens(tp) => tp.score_of(candidate.subpath),
             Self::ContentExact(cp) => cp.score_of(candidate),
             Self::ContentRegex(cp) => cp.score_of(candidate),
             Self::Composite(cp) => cp.score_of(candidate),
@@ -174,14 +170,14 @@ impl Pattern {
 
     pub fn score_of_string(&self, candidate: &str) -> Option<i32> {
         match self {
-            Self::NameExact(ep) => ep.score_of(&candidate),
-            Self::NameFuzzy(fp) => fp.score_of(&candidate),
-            Self::NameRegex(rp) => rp.find(&candidate).map(|m| m.score),
-            Self::NameTokens(tp) => tp.score_of(&candidate),
-            Self::PathExact(ep) => ep.score_of(&candidate),
-            Self::PathFuzzy(fp) => fp.score_of(&candidate),
-            Self::PathRegex(rp) => rp.find(&candidate).map(|m| m.score),
-            Self::PathTokens(tp) => tp.score_of(&candidate),
+            Self::NameExact(ep) => ep.score_of(candidate),
+            Self::NameFuzzy(fp) => fp.score_of(candidate),
+            Self::NameRegex(rp) => rp.find(candidate).map(|m| m.score),
+            Self::NameTokens(tp) => tp.score_of(candidate),
+            Self::PathExact(ep) => ep.score_of(candidate),
+            Self::PathFuzzy(fp) => fp.score_of(candidate),
+            Self::PathRegex(rp) => rp.find(candidate).map(|m| m.score),
+            Self::PathTokens(tp) => tp.score_of(candidate),
             Self::ContentExact(_) => None, // this isn't suitable
             Self::ContentRegex(_) => None, // this isn't suitable
             Self::Composite(cp) => cp.score_of_string(candidate),
@@ -197,16 +193,12 @@ impl Pattern {
     /// (it accepts everything)
     pub fn is_empty(&self) -> bool {
         match self {
-            Self::NameExact(ep) => ep.is_empty(),
-            Self::NameFuzzy(fp) => fp.is_empty(),
-            Self::NameRegex(rp) => rp.is_empty(),
-            Self::NameTokens(tp) => tp.is_empty(),
-            Self::PathExact(ep) => ep.is_empty(),
-            Self::PathFuzzy(fp) => fp.is_empty(),
-            Self::PathRegex(rp) => rp.is_empty(),
-            Self::PathTokens(tp) => tp.is_empty(),
+            Self::NameExact(ep) | Self::PathExact(ep) => ep.is_empty(),
             Self::ContentExact(ep) => ep.is_empty(),
+            Self::NameFuzzy(fp) | Self::PathFuzzy(fp) => fp.is_empty(),
+            Self::NameRegex(rp) | Self::PathRegex(rp) => rp.is_empty(),
             Self::ContentRegex(rp) => rp.is_empty(),
+            Self::NameTokens(tp) | Self::PathTokens(tp) => tp.is_empty(),
             Self::Composite(cp) => cp.is_empty(),
             Self::None => true,
         }
